==> admin-util-4.0-sources.jar: com/sun/enterprise/admin/remote/AdminCommandStateImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package com.sun.enterprise.admin.remote;

import org.glassfish.api.ActionReport;
import org.glassfish.api.admin.AdminCommandState;
import org.glassfish.api.admin.progress.JobInfo;
import org.glassfish.api.admin.progress.JobPersistence;
import org.glassfish.internal.api.Globals;

/** Basic implementation. Good for unmarshaling. 
 *
 * @author mmares
 */
public class AdminCommandStateImpl implements AdminCommandState {
    
    protected State state = State.PREPARED;
    private ActionReport actionReport;
    private boolean payloadIsEmpty;
    protected String id;


    public AdminCommandStateImpl(final State state, final ActionReport actionReport, 
            final boolean payloadIsEmpty, final String id) {
        this.state = state;
        this.actionReport = actionReport;
        this.payloadIsEmpty = payloadIsEmpty;
        this.id = id;
    }

    public AdminCommandStateImpl(String id) {
        this(State.PREPARED, null, true, id);
    }
    
    @Override
    public State getState() {
        return this.state;
    }

    @Override
    public void complete(ActionReport actionReport) {
        this.actionReport = actionReport;
        setState(State.COMPLETED);
    }

    @Override
    public ActionReport getActionReport() {
        return this.actionReport;
    }

    @Override
    public boolean isOutboundPayloadEmpty() {
        return this.payloadIsEmpty;
    }
    
    @Override
    public String getId() {
        return this.id;
    }
    
    protected void setState(State state) {
        this.state = state;
    }
    
}

==> admin-util-5.0.1-sources.jar: com/sun/enterprise/admin/remote/AdminCommandStateImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2012-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.admin.remote;

import java.io.Serializable;
import org.glassfish.api.ActionReport;
import org.glassfish.api.admin.AdminCommandState;

/** Basic implementation. Good for unmarshaling. 
 *
 * @author mmares
 */
public class AdminCommandStateImpl implements AdminCommandState, Serializable {
    
    private static final long serialVersionUID = 1L;
    
    protected State state = State.PREPARED;
    protected ActionReport actionReport;
    private boolean payloadIsEmpty;
    protected String id;


    public AdminCommandStateImpl(final State state, final ActionReport actionReport, 
            final boolean payloadIsEmpty, final String id) {
        this.state = state;
        this.actionReport = actionReport;
        this.payloadIsEmpty = payloadIsEmpty;
        this.id = id;
    }

    public AdminCommandStateImpl(String id) {
        this(State.PREPARED, null, true, id);
    }
    
    @Override
    public State getState() {
        return this.state;
    }

    @Override
    public void complete(ActionReport actionReport) {
        this.actionReport = actionReport;
        if (getState().equals(State.REVERTING)) {
            setState(State.REVERTED);
        } else {
            setState(State.COMPLETED);
        }
    }

    @Override
    public ActionReport getActionReport() {
        return this.actionReport;
    }

    @Override
    public boolean isOutboundPayloadEmpty() {
        return this.payloadIsEmpty;
    }
    
    @Override
    public String getId() {
        return this.id;
    }
    
    protected void setState(State state) {
        this.state = state;
    }
    
}
